RunModule — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »

# RunModule

Run a pywws module.

Many of the modules in the pywws package include a ‘main’ function that is run when that module is run as a script. Unfortunately running package modules as scripts has been deprecated, producing a ‘ValueError: Attempted relative import in non-package’ error. This program allows pywws module scripts to be run.

    usage: python RunModule.py module [module_options]
    module is a pywws module, e.g. ZambrettiCore
    module_options are options and parameters to be passed to the module

Fonctions

`main`([argv]) |

`RunModule.` `main`(argv=None)

### Navigation

- index
- modules |
- suivant |
- précédent |
- pywws 13.03_7f9fc90 documentation »
- Programmes et des modules Python »